Tutorials and FAQs
==================

The following introductory tutorial will help you get started with ``hera_sim``:

.. toctree::
   :maxdepth: 2

   tutorials/hera_sim_tour

The following tutorial will help you learn how use the ``Simulator`` class:

.. toctree::
   :maxdepth: 2

   tutorials/hera_sim_simulator

The following tutorial will help you learn how to interface with the ``defaults`` module:

.. toctree::
   :maxdepth: 2

   tutorials/hera_sim_defaults

The following tutorial will give you an overview of how to use ``hera_sim`` from the
command line to add instrumental systematics / noise to visibilities:

.. toctree::
   :maxdepth: 2

   tutorials/hera_sim_cli

The following tutorials will give you an overview of how to simulate visibilities from
sky models using ``hera_sim`` (first from an interpreter, then from the command line):

.. toctree::
   :maxdepth: 2

   tutorials/visibility_simulator
   tutorials/hera_sim_vis_cli
